@@ -125,12 +125,7 @@ public:
     /**
     * Checks if the given database path is equal to the current one
     */
-    bool imgDatabaseEqual(const QString& dbType, const QString& dbName, const QString& dbHostName, int dbPort, bool dbInternalServer) const;
-
-    /**
-    * Checks if the given database path is equal to the current one
-    */
-    bool tmbDatabaseEqual(const QString& dbType, const QString& dbName, const QString& dbHostName, int dbPort) const;
+    bool databaseEqual(const QString& dbType, const QString& dbName, const QString& dbHostName, int dbPort, bool dbInternalServer) const;
 
     /**
     * starts scanning the libraryPath and listing the albums. If the
