@@ -49,6 +49,8 @@ public:
 
     void toggleTagToSelected(int tagID);
 
+    void connectProgressSignals(QObject* progressManager);
+
 public Q_SLOTS:
 
     void openEditor();
@@ -81,6 +83,7 @@ public Q_SLOTS:
     void assignRating(const QList<QModelIndex>& index, int rating);
 
     void createGroupFromSelection();
+    void createGroupByTimeFromSelection();
     void ungroupSelected();
     void removeSelectedFromGroup();
 
