@@ -7,7 +7,7 @@
  * Description : Qt item view for images - the delegate
  *
  * Copyright (C) 2002-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at googlemail dot com>
  * Copyright (C) 2002-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
  *
@@ -63,6 +63,7 @@ void ImageDelegate::ImageDelegatePrivate::clearRects()
     modDateRect          = QRect(0, 0, 0, 0);
     pixmapRect           = QRect(0, 0, 0, 0);
     nameRect             = QRect(0, 0, 0, 0);
+    titleRect            = QRect(0, 0, 0, 0);
     commentsRect         = QRect(0, 0, 0, 0);
     resolutionRect       = QRect(0, 0, 0, 0);
     sizeRect             = QRect(0, 0, 0, 0);
@@ -283,6 +284,11 @@ void ImageDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const
         drawName(p, d->nameRect, info.name());
     }
 
+    if (!d->titleRect.isNull())
+    {
+        drawTitle(p, d->titleRect, info.title());
+    }
+
     if (!d->commentsRect.isNull())
     {
         drawComments(p, d->commentsRect, info.comment());
@@ -332,7 +338,7 @@ void ImageDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const
     if (d->drawImageFormat)
     {
         QString frm = info.format();
-        if (frm.contains("-")) frm = frm.section("-", -1);   // For RAW format annoted as "RAW-xxx" => "xxx"
+        if (frm.contains("-")) frm = frm.section('-', -1);   // For RAW format annoted as "RAW-xxx" => "xxx"
         drawImageFormat(p, actualPixmapRect, frm);
     }
 
