@@ -296,10 +296,16 @@ HistoryGraph::Vertex ImageHistoryGraphData::addVertex(const ImageInfo& info)
         //kDebug() << "Find by uuid" << uuid << ": found" << v.isNull();
         if (v.isNull())
         {
-            HistoryImageId id = info.historyImageId();
-            v = findVertexByProperties(id);
+            id = info.historyImageId();
+            v  = findVertexByProperties(id);
             //kDebug() << "Find by h-i-m" << ": found" << v.isNull();
         }
+
+        // Need to add new vertex. Do this through the method which will resolve the history id
+        if (v.isNull())
+        {
+            v = addVertex(id);
+        }
     }
 
     applyProperties(v, QList<ImageInfo>() << info, QList<HistoryImageId>() << id);
@@ -309,7 +315,7 @@ HistoryGraph::Vertex ImageHistoryGraphData::addVertex(const ImageInfo& info)
 
 HistoryGraph::Vertex ImageHistoryGraphData::addVertexScanned(qlonglong id)
 {
-    // short version where we dont read information about id from an ImageInfo
+    // short version where we do not read information about id from an ImageInfo
     Vertex v = findVertexByProperties(id);
 
     applyProperties(v, QList<ImageInfo>() << ImageInfo(id), QList<HistoryImageId>());
@@ -797,7 +803,7 @@ static QString toString(const HistoryVertexProperties& props)
         }
         else
         {
-            return QString("Ids: (") + ids.join(",") + ")";
+            return QString("Ids: (") + ids.join(",") + ')';
         }
     }
     else
