@@ -79,7 +79,7 @@ public:
 
     HistoryTreeItem* child(int index) const
     {
-        return children[index];
+        return children.at(index);
     }
 
 public:
@@ -386,7 +386,7 @@ void ImageHistoryGraphModel::ImageHistoryGraphModelPriv::buildImagesTree()
         }
         else if (currentLevel < previousLevel)
         {
-            for (int level = currentLevel; level < previousLevel; level++)
+            for (int level = currentLevel; level < previousLevel; ++level)
             {
                 parent = parent->parent;
             }
@@ -409,10 +409,10 @@ void ImageHistoryGraphModel::ImageHistoryGraphModelPriv::buildCombinedTree(const
 
     bool onePath = leavesFromRef.size() <= 1;
 
-    for (int i=0; i<path.size(); i++)
+    for (int i=0; i<path.size(); ++i)
     {
-        const HistoryGraph::Vertex& v = path[i];
-        HistoryGraph::Vertex previous = i ? path[i-1] : HistoryGraph::Vertex();
+        const HistoryGraph::Vertex& v = path.at(i);
+        HistoryGraph::Vertex previous = i ? path.at(i-1) : HistoryGraph::Vertex();
 //        HistoryGraph::Vertex next     = i < path.size() - 1 ? path[i+1] : HistoryGraph::Vertex();
         //kDebug() << "Vertex on path" << path[i];
         // create new item
@@ -513,9 +513,9 @@ void ImageHistoryGraphModel::ImageHistoryGraphModelPriv::
         QList<HistoryGraph::Vertex> shortestPath = graph().shortestPath(showActionsFrom, v);
 
         // add all filter actions showActionsFrom -> v above item
-        for (int i=1; i<shortestPath.size(); i++)
+        for (int i=1; i<shortestPath.size(); ++i)
         {
-            HistoryEdgeProperties props = graph().properties(shortestPath[i], shortestPath[i-1]);
+            HistoryEdgeProperties props = graph().properties(shortestPath.at(i), shortestPath.at(i-1));
             foreach (const FilterAction& action, props.actions)
             {
                 parentItem->addItem(createFilterActionItem(action));
@@ -560,7 +560,7 @@ void ImageHistoryGraphModel::ImageHistoryGraphModelPriv::
     VertexItem* item = 0;
     bool isFirst     = true;
 
-    for (int i=1; i<infos.size(); i++)
+    for (int i=1; i<infos.size(); ++i)
     {
         if (isFirst)
         {
@@ -571,7 +571,7 @@ void ImageHistoryGraphModel::ImageHistoryGraphModelPriv::
             parentItem->addItem(new SeparatorItem);
         }
 
-        item = createVertexItem(vertex, infos[i]);
+        item = createVertexItem(vertex, infos.at(i));
         parentItem->addItem(item);
     }
 }
