@@ -6,7 +6,7 @@
  * Date        : 2009-02-18
  * Description : Channel mixer settings view.
  *
- * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -62,6 +62,8 @@ public:
 
     MixerSettingsPriv() :
         currentChannel(RedChannel),
+        monochromeTips(0),
+        totalPercents(0),
         resetButton(0),
         preserveLuminosity(0),
         monochrome(0),
@@ -87,6 +89,9 @@ public:
 
     int                   currentChannel;
 
+    QLabel*               monochromeTips;
+    QLabel*               totalPercents;
+
     QPushButton*          resetButton;
 
     QCheckBox*            preserveLuminosity;
@@ -121,7 +126,7 @@ MixerSettings::MixerSettings(QWidget* parent)
 {
     QGridLayout* grid = new QGridLayout(this);
 
-    QLabel* redLabel  = new QLabel(i18n("Red:"));
+    QLabel* redLabel  = new QLabel(i18n("Red (%):"));
     d->redGain        = new RDoubleNumInput;
     d->redGain->setDecimals(1);
     d->redGain->setRange(-200.0, 200.0, 1);
@@ -129,7 +134,7 @@ MixerSettings::MixerSettings(QWidget* parent)
     d->redGain->setWhatsThis(i18n("Select the red color gain, as a percentage, "
                                   "for the current channel."));
 
-    QLabel* greenLabel = new QLabel(i18n("Green:"));
+    QLabel* greenLabel = new QLabel(i18n("Green (%):"));
     d->greenGain       = new RDoubleNumInput;
     d->greenGain->setDecimals(1);
     d->greenGain->setRange(-200.0, 200.0, 1);
@@ -137,7 +142,7 @@ MixerSettings::MixerSettings(QWidget* parent)
     d->greenGain->setWhatsThis(i18n("Select the green color gain, as a percentage, "
                                     "for the current channel."));
 
-    QLabel* blueLabel = new QLabel(i18n("Blue:"));
+    QLabel* blueLabel = new QLabel(i18n("Blue (%):"));
     d->blueGain       = new RDoubleNumInput;
     d->blueGain->setDecimals(1);
     d->blueGain->setRange(-200.0, 200.0, 1);
@@ -145,24 +150,40 @@ MixerSettings::MixerSettings(QWidget* parent)
     d->blueGain->setWhatsThis(i18n("Select the blue color gain, as a percentage, "
                                    "for the current channel."));
 
+    // -------------------------------------------------------------
+
     d->resetButton = new QPushButton(i18n("&Reset"));
     d->resetButton->setIcon(KIconLoader::global()->loadIcon("document-revert", KIconLoader::Toolbar));
     d->resetButton->setWhatsThis(i18n("Reset color channels' gains settings from "
                                       "the currently selected channel."));
 
+    d->totalPercents = new QLabel();
+    d->totalPercents->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    
     // -------------------------------------------------------------
 
-    d->monochrome = new QCheckBox(i18n("Monochrome"));
-    d->monochrome->setWhatsThis(i18n("Enable this option if you want the image rendered "
-                                     "in monochrome mode. "
-                                     "In this mode, the histogram will display only luminosity values."));
-
     d->preserveLuminosity = new QCheckBox(i18n("Preserve luminosity"));
     d->preserveLuminosity->setWhatsThis(i18n("Enable this option is you want preserve "
                                         "the image luminosity."));
 
     // -------------------------------------------------------------
 
+    d->monochrome     = new QCheckBox(i18n("Monochrome"));
+    d->monochromeTips = new QLabel(i18n("<p>Use <b>Monochrome</b> mode to convert color picture to Black and White:</p>"
+                                        "<p>The <qt><font color=\"red\">red channel</font></qt> modifies <a href='http://en.wikipedia.org/wiki/Contrast_(vision)'>the contrast</a> of photograph.</p>"
+                                        "<p>The <qt><font color=\"green\">green channel</font></qt> enhances or reduces the details level of photograph.</p>"
+                                        "<p>The <qt><font color=\"blue\">blue channel</font></qt> affects <a href='http://en.wikipedia.org/wiki/Image_noise'>the noise</a> of photograph.</p>"
+                                        "<p><u>Note:</u> in this mode, the histogram will display only luminosity values.</p>"));
+
+    d->monochromeTips->setEnabled(false);
+    d->monochromeTips->setFont(KGlobalSettings::smallestReadableFont());
+    d->monochromeTips->setWordWrap(true);
+    d->monochromeTips->setOpenExternalLinks(true);
+    d->monochromeTips->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
+    d->monochromeTips->setLineWidth(1);
+
+    // -------------------------------------------------------------
+
     grid->addWidget(redLabel,              0, 0, 1, 1);
     grid->addWidget(d->redGain,            0, 1, 1, 4);
     grid->addWidget(greenLabel,            1, 0, 1, 1);
@@ -170,9 +191,12 @@ MixerSettings::MixerSettings(QWidget* parent)
     grid->addWidget(blueLabel,             2, 0, 1, 1);
     grid->addWidget(d->blueGain,           2, 1, 1, 4);
     grid->addWidget(d->resetButton,        3, 0, 1, 2);
-    grid->addWidget(d->monochrome,         4, 0, 1, 5);
-    grid->addWidget(d->preserveLuminosity, 5, 0, 1, 5);
-    grid->setRowStretch(6, 10);
+    grid->addWidget(d->totalPercents,      3, 3, 1, 1);
+    grid->addWidget(d->preserveLuminosity, 4, 0, 1, 5);
+    grid->addWidget(d->monochrome,         5, 0, 1, 5);
+    grid->addWidget(d->monochromeTips,     6, 0, 1, 5);
+    grid->setRowStretch(7, 10);
+    grid->setColumnStretch(2, 10);
     grid->setMargin(KDialog::spacingHint());
     grid->setSpacing(KDialog::spacingHint());
 
@@ -202,6 +226,11 @@ MixerSettings::~MixerSettings()
     delete d;
 }
 
+void MixerSettings::setMonochromeTipsVisible(bool b)
+{
+    b ? d->monochromeTips->show() : d->monochromeTips->hide();
+}
+
 void MixerSettings::setCurrentChannel(int channel)
 {
     d->currentChannel = channel;
@@ -294,10 +323,18 @@ void MixerSettings::slotGainsChanged()
             break;
         }
     }
-
+    
+    updateTotalPercents();
     emit signalSettingsChanged();
 }
 
+void MixerSettings::updateTotalPercents()
+{
+    double total = d->redGain->value() + d->greenGain->value() + d->blueGain->value();
+    QString str;
+    d->totalPercents->setText(i18n("Total: %1 (%)", str.sprintf("%3.1f", total)));
+} 
+
 void MixerSettings::updateSettingsWidgets()
 {
     d->monochrome->blockSignals(true);
@@ -357,6 +394,7 @@ void MixerSettings::updateSettingsWidgets()
 
     d->monochrome->setChecked(d->mixerSettings.bMonochrome);
     d->preserveLuminosity->setChecked(d->mixerSettings.bPreserveLum);
+    updateTotalPercents();
 
     d->monochrome->blockSignals(false);
     d->preserveLuminosity->blockSignals(false);
@@ -367,14 +405,15 @@ void MixerSettings::updateSettingsWidgets()
 
 void MixerSettings::slotMonochromeActived(bool mono)
 {
-    d->mixerSettings.bMonochrome = d->monochrome->isChecked();
+    d->mixerSettings.bMonochrome = mono;
+    d->monochromeTips->setEnabled(mono);
     emit signalMonochromeActived(mono);
     emit signalSettingsChanged();
 }
 
-void MixerSettings::slotLuminosityChanged(bool)
+void MixerSettings::slotLuminosityChanged(bool lum)
 {
-    d->mixerSettings.bPreserveLum = d->preserveLuminosity->isChecked();
+    d->mixerSettings.bPreserveLum = lum;
     emit signalSettingsChanged();
 }
 
@@ -502,6 +541,7 @@ void MixerSettings::loadSettings()
 
         fgets(buf1, 1023, fp);
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s", buf1);
 
 //        // Get the current output channel in dialog.
@@ -519,8 +559,10 @@ void MixerSettings::loadSettings()
 //            currentOutputChannel = BlueChannel;
 //        }
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s", buf1); // preview flag, preserved for compatibility
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s", buf1);
 
         if (strcmp (buf1, "true") == 0)
@@ -532,6 +574,7 @@ void MixerSettings::loadSettings()
             settings.bMonochrome = false;
         }
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s", buf1);
 
         if (strcmp (buf1, "true") == 0)
@@ -543,21 +586,25 @@ void MixerSettings::loadSettings()
             settings.bPreserveLum = false;
         }
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s %s %s", buf1, buf2, buf3);
         settings.redRedGain   = atof(buf1);
         settings.redGreenGain = atof(buf2);
         settings.redBlueGain  = atof(buf3);
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s %s %s", buf1, buf2, buf3);
         settings.greenRedGain   = atof(buf1);
         settings.greenGreenGain = atof(buf2);
         settings.greenBlueGain  = atof(buf3);
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s %s %s", buf1, buf2, buf3);
         settings.blueRedGain   = atof(buf1);
         settings.blueGreenGain = atof(buf2);
         settings.blueBlueGain  = atof(buf3);
 
+        // FIXME: scanf without field width limits can crash with huge input data
         fscanf (fp, "%*s %s %s %s", buf1, buf2, buf3);
         settings.blackRedGain   = atof(buf1);
         settings.blackGreenGain = atof(buf2);
