@@ -781,15 +781,16 @@ void ThumbnailLoadThread::startKdePreviewJob()
         return;
     }
 
+    d->kdeJobHash.clear();
     KUrl::List list;
     foreach (const LoadingDescription& description, d->kdeTodo)
     {
-        KUrl url           = KUrl::fromPath(description.filePath);
+        KUrl url = KUrl::fromPath(description.filePath);
         list << url;
         d->kdeJobHash[url] = description;
     }
     d->kdeTodo.clear();
-    d->kdeJob = KIO::filePreview(list, d->creator->storedSize()); // do not know if size 0 is allowed
+    d->kdeJob = KIO::filePreview(list, d->creator->storedSize()); // FIXME: do not know if size 0 is allowed
 
     connect(d->kdeJob, SIGNAL(gotPreview(KFileItem,QPixmap)),
             this, SLOT(gotKDEPreview(KFileItem,QPixmap)));
@@ -803,8 +804,13 @@ void ThumbnailLoadThread::startKdePreviewJob()
 
 void ThumbnailLoadThread::gotKDEPreview(const KFileItem& item, const QPixmap& kdepix)
 {
+    if (!d->kdeJobHash.contains(item.url()))
+    {
+        return;
+    }
+
+    LoadingDescription description = d->kdeJobHash.value(item.url());
     QPixmap pix;
-    LoadingDescription description = d->kdeJobHash[item.url()];
 
     if (kdepix.isNull())
     {
