@@ -6,7 +6,7 @@
  * Date        : 2009-08-08
  * Description : an option to provide file information to the parser
  *
- * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,7 +29,6 @@
 
 // KDE includes
 
-#include <kiconloader.h>
 #include <klocale.h>
 
 static const QString KEY_FILE("[file]");
@@ -41,7 +40,7 @@ namespace Digikam
 {
 
 FilePropertiesOption::FilePropertiesOption()
-    : Option(i18n("File"), i18n("Add file properties"), SmallIcon("folder-image"))
+    : Option(i18n("File"), i18n("Add file properties"), "folder-image")
 {
     setUseTokenMenu(true);
 
