@@ -32,6 +32,7 @@
 // KDE includes
 
 #include <kdebug.h>
+#include <klocale.h>
 
 // Local includes
 
@@ -703,7 +704,7 @@ void Benchmarker::process(FacePipelineExtendedPackage::Ptr package)
             }
             else
             {
-                kDebug() << "The image, truely without faces, is false-positive";
+                kDebug() << "The image, truly without faces, is false-positive";
                 ++falsePositiveImages;
             }
         }
@@ -772,7 +773,7 @@ QString Benchmarker::result() const
                    "</p>"
                    "<p>"
                    "In other words, if a face is detected as face, it will "
-                   "with a probability of %7% truely be a face. "
+                   "with a probability of %7% truly be a face. "
                    "Of all true faces, %6% will be detected. "
                    "Given face with no images on it, the detector will with a probability "
                    "of %5% falsely find a face on it. "
@@ -881,6 +882,7 @@ FacePipeline::FacePipelinePriv::FacePipelinePriv(FacePipeline* q)
     infosForFiltering    = 0;
     packagesOnTheRoad    = 0;
     maxPackagesOnTheRoad = 50;
+    totalPackagesAdded   = 0;
 }
 
 void FacePipeline::FacePipelinePriv::processBatch(const QList<ImageInfo>& infos)
@@ -960,6 +962,7 @@ FacePipeline::FacePipelinePriv::buildPackage(const ImageInfo& info, const FacePi
 void FacePipeline::FacePipelinePriv::send(FacePipelineExtendedPackage::Ptr package)
 {
     start();
+    ++totalPackagesAdded;
     if (senderFlowControl(package))
     {
         ++packagesOnTheRoad;
@@ -971,6 +974,7 @@ void FacePipeline::FacePipelinePriv::finishProcess(FacePipelineExtendedPackage::
 {
     packagesOnTheRoad--;
     emit q->processed(*package);
+    emit q->progressValueChanged(float(packagesOnTheRoad + delayedPackages.size()) / totalPackagesAdded);
     package = 0;
 
     if (previewThread)
@@ -997,6 +1001,7 @@ void FacePipeline::FacePipelinePriv::receiverFlowControl()
 {
     if (!delayedPackages.isEmpty() && packagesOnTheRoad <= maxPackagesOnTheRoad)
     {
+        --totalPackagesAdded; // do not add twice
         send(delayedPackages.takeFirst());
     }
 }
@@ -1013,6 +1018,7 @@ void FacePipeline::FacePipelinePriv::checkFinished()
 
     if (hasFinished())
     {
+        totalPackagesAdded = 0;
         emit q->finished();
         // stop threads
         stop();
@@ -1041,6 +1047,7 @@ void FacePipeline::FacePipelinePriv::start()
     }
 
     started = true;
+    emit q->started(i18n("Applying face changes"));
 }
 
 void FacePipeline::FacePipelinePriv::stop()
