@@ -71,16 +71,12 @@ public:
     void    load(const QString& filename, IOFileSettingsContainer* IOFileSettings);
     void    preload(const QString& filename);
 
-    void    saveAs(const QString& filename, IOFileSettingsContainer* IOFileSettings,
-                   bool setExifOrientationTag, const QString& mimeType=QString());
     void    resetImage();
     void    abortSaving();
     void    applyTransform(const IccTransform& transform);
     void    setModified();
     void    readMetadataFromFile(const QString& file);
     QString ensureHasCurrentUuid() const;
-    void    clearUndoHistory();
-    void    setUndoHistoryOrigin();
     DImg    currentImage() const;
     QString currentImageFileFormat() const;
     QString currentImageFilePath() const;
