@@ -476,6 +476,8 @@ void ImageWindow::setupUserArea()
     d->imageFilterModel->setCategorizationMode(ImageSortSettings::NoCategories);
     d->imageFilterModel->setSortRole((ImageSortSettings::SortRole)AlbumSettings::instance()->getImageSortOrder());
     d->imageFilterModel->setSortOrder((ImageSortSettings::SortOrder)AlbumSettings::instance()->getImageSorting());
+    d->imageFilterModel->setAllGroupsOpen(true); // disable filtering out by group, see bug #283847
+    d->imageFilterModel->sort(0); // an initial sorting is necessary
 
     d->dragDropHandler  = new ImageDragDropHandler(d->imageInfoModel);
     d->dragDropHandler->setReadOnlyDrop(true);
@@ -1128,7 +1130,7 @@ void ImageWindow::saveAsIsComplete()
     if (!d->imageInfoModel->hasImage(d->currentImageInfo))
     {
         d->imageInfoModel->addImageInfoSynchronously(d->currentImageInfo);
-        // Note: Due to the asynchronous process, we dont yet have an index for the just added info!
+        // Note: Due to the asynchronous process, we do not yet have an index for the just added info!
         //d->imageInfoModel->addImageInfo(d->currentImageInfo);
     }
 
