@@ -8,7 +8,7 @@
  *
  * Copyright (C) 2004      by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio.fuoglio@gmail.com>
- * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -1390,22 +1390,22 @@ void SlideShowGL::effectCube()
 
     glLoadIdentity();
 
-    float PI    = 4.0 * atan(1.0);
+//    float PI    = 4.0 * atan(1.0);
     float znear = 3.0;
-    float theta = 2.0 * atan2((float)2.0 / (float)2.0, (float)znear);
-    theta       = theta * 180.0 / PI;
+//    float theta = 2.0 * atan2((float)2.0 / (float)2.0, (float)znear);
+//    theta       = theta * 180.0 / PI;
 
     glFrustum(-1.0, 1.0, -1.0, 1.0, znear - 0.01, 10.0);
 
     static float xrot;
     static float yrot;
-    static float zrot;
+//    static float zrot;
 
     if (m_i == 0)
     {
         xrot = 0.0;
         yrot = 0.0;
-        zrot = 0.0;
+//        zrot = 0.0;
     }
 
     glMatrixMode( GL_MODELVIEW );
