@@ -54,6 +54,7 @@
 #include <kmimetype.h>
 #include <kstandarddirs.h>
 #include <ktoolinvocation.h>
+#include <kguiitem.h>
 
 // LibKExiv2 includes
 
@@ -272,9 +273,11 @@ void FlickrTalker::slotAuthenticate()
 
     KToolInvocation::invokeBrowser(url.url());
     int valueOk = KMessageBox::questionYesNo(kapp->activeWindow(),
-                  i18n("Please follow the instructions in the browser window, then "
-                       "return to press Yes if you are authenticated, or No otherwise."),
-                  i18n("%1 Service Web Authorization", m_serviceName));
+                    i18n("Please follow the instructions in the browser window, then "
+                         "return to press corresponding button."),
+                    i18n("%1 Service Web Authorization", m_serviceName),
+                    KGuiItem(i18n("I am authenticated"), "dialog-ok"),
+                    KGuiItem(i18n("I am not authenticated"), "dialog-cancel"));
 
     if( valueOk == KMessageBox::Yes)
     {
@@ -530,7 +533,7 @@ void FlickrTalker::addPhotoToPhotoSet(const QString& photoId,
 }
 
 bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
-                            bool rescale, int maxDim, int imageQuality)
+                            bool sendOriginal, bool rescale, int maxDim, int imageQuality)
 {
     if (m_job)
     {
@@ -606,12 +609,18 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
     {
         path = KStandardDirs::locateLocal("tmp", QFileInfo(photoPath).baseName().trimmed() + ".jpg");
 
-        if (rescale && (image.width() > maxDim || image.height() > maxDim))
-            image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio,
+        if (sendOriginal)
+        {
+            QFile imgFile(photoPath);
+            imgFile.copy(path);
+        }
+        else
+        {
+            if (rescale && (image.width() > maxDim || image.height() > maxDim))
+                image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio,
                                                  Qt::SmoothTransformation);
-
-        image.save(path, "JPEG", imageQuality);
-
+            image.save(path, "JPEG", imageQuality);
+        }
         // Restore all metadata.
 
         KExiv2Iface::KExiv2 exiv2Iface;
@@ -1056,7 +1065,7 @@ void FlickrTalker::parseResponseCreatePhotoSet(const QByteArray& data)
                     it->id = new_id;
                     break;
                 }
-                it++;
+                ++it;
             }
             // Set the new id in the selected photo set.
             m_selectedPhotoSet.id = new_id;
