@@ -32,7 +32,6 @@
 // Qt includes
 
 #include <QCheckBox>
-#include <QComboBox>
 #include <QDoubleValidator>
 #include <QFormLayout>
 #include <QIntValidator>
@@ -41,6 +40,7 @@
 
 // KDE includes
 
+#include <kcombobox.h>
 #include <kconfiggroup.h>
 #include <kglobal.h>
 #include <klineedit.h>
@@ -89,7 +89,7 @@ public:
     QCheckBox*                   cbNSatellites;
     KLineEdit*                   leNSatellites;
     QCheckBox*                   cbFixType;
-    QComboBox*                   comboFixType;
+    KComboBox*                   comboFixType;
     QCheckBox*                   cbDop;
     KLineEdit*                   leDop;
 
@@ -148,7 +148,7 @@ GPSImageDetails::GPSImageDetails(QWidget* const parent, KipiImageModel* const im
     formLayout->addRow(d->cbNSatellites, d->leNSatellites);
 
     d->cbFixType = new QCheckBox(i18n("Fix type"), this);
-    d->comboFixType = new QComboBox(this);
+    d->comboFixType = new KComboBox(this);
     d->comboFixType->addItem(i18n("2-d"), QVariant(2));
     d->comboFixType->addItem(i18n("3-d"), QVariant(3));
     formLayout->addRow(d->cbFixType, d->comboFixType);
