@@ -41,10 +41,12 @@
 #include "manager.h"
 #include "actionthread.h"
 #include "aboutdata.h"
+
 #include "intropage.h"
 #include "itemspage.h"
 #include "preprocessingpage.h"
 #include "optimizepage.h"
+#include "previewpage.h"
 #include "lastpage.h"
 
 namespace KIPIPanoramaPlugin
@@ -58,6 +60,7 @@ struct ImportWizardDlg::ImportWizardDlgPriv
         itemsPage(0),
         preProcessingPage(0),
         optimizePage(0),
+        previewPage(0),
         lastPage(0)
     {
     }
@@ -68,6 +71,7 @@ struct ImportWizardDlg::ImportWizardDlgPriv
     ItemsPage*          itemsPage;
     PreProcessingPage*  preProcessingPage;
     OptimizePage*       optimizePage;
+    PreviewPage*        previewPage;
     LastPage*           lastPage;
 };
 
@@ -78,10 +82,11 @@ ImportWizardDlg::ImportWizardDlg(Manager* mngr, QWidget* parent)
     setWindowTitle(i18n("Panorama Creator Wizard"));
 
     d->mngr              = mngr;
-    d->introPage         = new IntroPage(this);
+    d->introPage         = new IntroPage(d->mngr, this);
     d->itemsPage         = new ItemsPage(d->mngr, this);
     d->preProcessingPage = new PreProcessingPage(d->mngr, this);
     d->optimizePage      = new OptimizePage(d->mngr, this);
+    d->previewPage       = new PreviewPage(d->mngr, this);
     d->lastPage          = new LastPage(d->mngr, this);
 
     // ---------------------------------------------------------------
@@ -105,11 +110,23 @@ ImportWizardDlg::ImportWizardDlg(Manager* mngr, QWidget* parent)
     connect(d->itemsPage, SIGNAL(signalItemsPageIsValid(bool)),
             this, SLOT(slotItemsPageIsValid(bool)));
 
-    connect(d->preProcessingPage, SIGNAL(signalPreProcessed(const ItemUrlsMap&)),
-            this, SLOT(slotPreProcessed(const ItemUrlsMap&)));
+    connect(d->preProcessingPage, SIGNAL(signalPreProcessed(ItemUrlsMap)),
+            this, SLOT(slotPreProcessed(ItemUrlsMap)));
 
-    connect(d->optimizePage, SIGNAL(signalOptimized(const KUrl&)),
-            this, SLOT(slotOptimized(const KUrl&)));
+    connect(d->optimizePage, SIGNAL(signalOptimized(KUrl)),
+            this, SLOT(slotOptimized(KUrl)));
+
+    connect(d->previewPage, SIGNAL(signalPreviewGenerated(KUrl)),
+            this, SLOT(slotPreviewProcessed(KUrl)));
+
+    connect(d->previewPage, SIGNAL(signalPreviewGenerating()),
+            this, SLOT(slotPreviewProcessing()));
+
+    connect(d->previewPage, SIGNAL(signalStitchingFinished(KUrl)),
+            this, SLOT(slotStitchingFinished(KUrl)));
+
+    connect(d->lastPage, SIGNAL(signalCopyFinished()),
+            this, SLOT(slotCopyFinished()));
 }
 
 ImportWizardDlg::~ImportWizardDlg()
@@ -117,11 +134,6 @@ ImportWizardDlg::~ImportWizardDlg()
     delete d;
 }
 
-void ImportWizardDlg::slotHelp()
-{
-    KToolInvocation::invokeHelp("panorama", "kipi-plugins");
-}
-
 Manager* ImportWizardDlg::manager() const
 {
     return d->mngr;
@@ -140,7 +152,7 @@ void ImportWizardDlg::next()
     }
     else if (currentPage() == d->preProcessingPage->page())
     {
-        // Do not give acces to Next button during pre-processing.
+        // Do not give access to Next button during pre-processing.
         setValid(d->preProcessingPage->page(), false);
         d->preProcessingPage->process();
         // Next is handled with signals/slots
@@ -148,12 +160,30 @@ void ImportWizardDlg::next()
     }
     else if (currentPage() == d->optimizePage->page())
     {
-        // Do not give acces to Next button during optimization.
+        // Do not give access to Next button during optimization.
         setValid(d->optimizePage->page(), false);
         d->optimizePage->process();
         // Next is handled with signals/slots
         return;
     }
+    else if (currentPage() == d->previewPage->page())
+    {
+        // Cancel any preview being processed
+        d->previewPage->cancel();
+
+        // And start the final stitching process
+        setValid(d->previewPage->page(), false);
+        d->previewPage->startStitching();
+
+        // Next will be handled using signals/slots
+        return;
+    }
+    else if (currentPage() == d->lastPage->page())
+    {
+       setValid(d->lastPage->page(), false);
+       d->lastPage->copyFiles();
+        return;
+    }
 
     KAssistantDialog::next();
 }
@@ -163,21 +193,43 @@ void ImportWizardDlg::back()
     if (currentPage() == d->preProcessingPage->page())
     {
         d->preProcessingPage->cancel();
-        KAssistantDialog::back();
         setValid(d->preProcessingPage->page(), true);
-        return;
     }
     else if (currentPage() == d->optimizePage->page())
     {
         d->optimizePage->cancel();
-        KAssistantDialog::back();
         setValid(d->optimizePage->page(), true);
+
+        d->preProcessingPage->resetPage();
+    }
+    else if (currentPage() == d->previewPage->page())
+    {
+        d->previewPage->cancel();
+        setValid(d->previewPage->page(), true);
+
+        d->optimizePage->resetPage();
+    }
+    else if (currentPage() == d->lastPage->page())
+    {
+        KAssistantDialog::back();
+        d->previewPage->resetPage();
         return;
     }
 
     KAssistantDialog::back();
 }
 
+void ImportWizardDlg::accept()
+{
+    setValid(d->lastPage->page(), false);
+    d->lastPage->copyFiles();
+}
+
+void ImportWizardDlg::slotItemsPageIsValid(bool valid)
+{
+    setValid(d->itemsPage->page(), valid);
+}
+
 void ImportWizardDlg::slotPreProcessed(const ItemUrlsMap& map)
 {
     if (map.isEmpty())
@@ -189,6 +241,7 @@ void ImportWizardDlg::slotPreProcessed(const ItemUrlsMap& map)
     {
         // pre-processing Done.
         d->mngr->setPreProcessedMap(map);
+        setValid(d->preProcessingPage->page(), true);
         KAssistantDialog::next();
     }
 }
@@ -202,14 +255,46 @@ void ImportWizardDlg::slotOptimized(const KUrl& ptoUrl)
     }
     else
     {
+        d->mngr->setAutoOptimiseUrl(ptoUrl);
+
         // Optimization finished.
+        setValid(d->optimizePage->page(), true);
         KAssistantDialog::next();
+
+        // Start the Preview generation
+        d->previewPage->computePreview();
     }
 }
 
-void ImportWizardDlg::slotItemsPageIsValid(bool valid)
+void ImportWizardDlg::slotPreviewProcessing()
 {
-    setValid(d->itemsPage->page(), valid);
+    //setValid(d->previewPage->page(), false);
+}
+
+void ImportWizardDlg::slotPreviewProcessed(const KUrl& /*url*/)
+{
+    //setValid(d->previewPage->page(), !url.equals(KUrl()));
+}
+
+void ImportWizardDlg::slotStitchingFinished(const KUrl& url)
+{
+    if (url != KUrl())
+    {
+        d->mngr->setPanoUrl(url);
+    }
+    setValid(d->previewPage->page(), true);
+    KAssistantDialog::next();
+    d->lastPage->resetTitle();
+}
+
+void ImportWizardDlg::slotCopyFinished()
+{
+    QDialog::accept();
+}
+
+void ImportWizardDlg::slotHelp()
+{
+    KToolInvocation::invokeHelp("panorama", "kipi-plugins");
 }
 
 } // namespace KIPIPanoramaPlugin
