@@ -655,6 +655,7 @@ bool ActionThread::computePanoramaPreview(KUrl& ptoUrl, KUrl& previewUrl, const
     QStringList pto;
     if (!input.open(QIODevice::ReadOnly | QIODevice::Text))
     {
+        errors = i18n("Cannot read project file");
         kDebug() << "Can't read PTO File!";
         return false;
     }
@@ -667,11 +668,18 @@ bool ActionThread::computePanoramaPreview(KUrl& ptoUrl, KUrl& previewUrl, const
         }
         input.close();
     }
+    if (pto.count() == 0)
+    {
+        errors = i18n("Empty project file.");
+        kDebug() << "Pto file empty!!";
+        return false;
+    }
 
     ptoUrl.setFileName("preview.pto");
     input.setFileName(ptoUrl.toLocalFile());
     if (!input.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate))
     {
+        errors = i18n("Preview project file cannot be created.");
         kDebug() << "Can't create a new PTO File!";
         return false;
     }
@@ -682,14 +690,20 @@ bool ActionThread::computePanoramaPreview(KUrl& ptoUrl, KUrl& previewUrl, const
     KExiv2 metaPreview(preProcessedUrlsMap.begin().value().previewUrl.toLocalFile());
     double scalingFactor = ((double) metaPreview.getPixelSize().width()) / ((double) metaOrig.getPixelSize().width());
 
-    foreach (QString line, pto)
+    foreach (const QString& line, pto)
     {
+        if (line.isEmpty())
+        {
+            continue;
+        }
+
         QString tmp;
         QStringList parameters = line.split(' ', QString::SkipEmptyParts);
+
         if (line[0] == 'p')
         {
-            tmp = "";
-            foreach (QString p, parameters)
+            tmp.clear();
+            foreach (const QString& p, parameters)
             {
                 if (p[0] == 'w' || p[0] == 'h')
                 {
@@ -715,16 +729,16 @@ bool ActionThread::computePanoramaPreview(KUrl& ptoUrl, KUrl& previewUrl, const
         }
         else if (line[0] == 'i')
         {
-            tmp = "";
+            tmp.clear();
             QStringList realParameters;
             bool nRead = false;
-            foreach (QString p, parameters)
+            foreach (const QString& p, parameters)
             {
                 if (p[0] != 'n')
                 {
                     if (nRead)
                     {
-                        realParameters[realParameters.size() - 1] += " " + p;
+                        realParameters[realParameters.size() - 1] += ' ' + p;
                     }
                     else
                     {
@@ -737,7 +751,7 @@ bool ActionThread::computePanoramaPreview(KUrl& ptoUrl, KUrl& previewUrl, const
                     realParameters << p;
                 }
             }
-            foreach (QString p, realParameters)
+            foreach (const QString& p, realParameters)
             {
                 if (p[0] == 'w')
                 {
@@ -758,6 +772,7 @@ bool ActionThread::computePanoramaPreview(KUrl& ptoUrl, KUrl& previewUrl, const
                     if (it == preProcessedUrlsMap.end())
                     {
                         input.close();
+                        errors = i18n("Unknown input file in the project file: %1", imgFileName);
                         kDebug() << "Unknown input File in the PTO: " << imgFileName;
                         kDebug() << "IMG: " << imgUrl.toLocalFile();
                         return false;
@@ -792,12 +807,14 @@ bool ActionThread::computePanoramaPreview(KUrl& ptoUrl, KUrl& previewUrl, const
     KUrl mkUrl;
     if (!createMK(ptoUrl, mkUrl, previewUrl, JPEG, errors))
     {
+        errors = i18n("Cannot create Makefile.");
         kDebug() << "Makefile creation failed!";
         return false;
     }
 
     if (!compileMK(mkUrl, errors))
     {
+        errors = i18n("Preview cannot be processed.");
         kDebug() << "Makefile execution failed!";
         return false;
     }
@@ -809,7 +826,7 @@ bool ActionThread::computePreview(const KUrl& inUrl, KUrl& outUrl)
 {
     outUrl = d->preprocessingTmpDir->name();
     QFileInfo fi(inUrl.toLocalFile());
-    outUrl.setFileName(fi.completeBaseName().replace(".", "_") + QString("-preview.jpg"));
+    outUrl.setFileName(fi.completeBaseName().replace('.', '_') + QString("-preview.jpg"));
 
     QImage img;
     if (img.load(inUrl.toLocalFile()))
@@ -867,8 +884,15 @@ bool ActionThread::convertRaw(const KUrl& inUrl, KUrl& outUrl, const RawDecoding
             sptr += 6;
         }
 
-        KExiv2 meta;
-        meta.load(inUrl.toLocalFile());
+        KExiv2 meta, meta_orig;
+        meta_orig.load(inUrl.toLocalFile());
+        KExiv2::MetaDataMap m = meta_orig.getExifTagsDataList(QStringList("Photo"), true);
+        KExiv2::MetaDataMap::iterator it;
+        for (it = m.begin(); it != m.end(); ++it)
+        {
+            meta_orig.removeExifTag(it.key().toAscii().data(), false);
+        }
+        meta.setData(meta_orig.data());
         meta.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
         meta.setImageDimensions(QSize(width, height));
         meta.setExifTagString("Exif.Image.DocumentName", inUrl.fileName());
@@ -883,7 +907,7 @@ bool ActionThread::convertRaw(const KUrl& inUrl, KUrl& outUrl, const RawDecoding
         wImageIface.setImageData(imageData, width, height, true, false, prof, meta);
         outUrl = d->preprocessingTmpDir->name();
         QFileInfo fi(inUrl.toLocalFile());
-        outUrl.setFileName(fi.completeBaseName().replace(".", "_") + QString(".tif"));
+        outUrl.setFileName(fi.completeBaseName().replace('.', '_') + QString(".tif"));
 
         if (!wImageIface.write2TIFF(outUrl.toLocalFile()))
             return false;
@@ -1172,7 +1196,7 @@ bool ActionThread::compileMKStepByStep(KUrl& mkUrl, const ItemUrlsMap& urlList,
         ad2.id              = i;
         ad2.outUrl          = KUrl(d->preprocessingTmpDir->name());
         ad2.outUrl.setFileName(mkFile);
-        #pragma omp critical
+#pragma omp critical
         {
             emit finished(ad2);
         }
@@ -1234,7 +1258,7 @@ bool ActionThread::copyFiles(const KUrl& panoUrl, const KUrl& finalPanoUrl, cons
         errors = i18n("Cannot move panorama from %1 to %2.",
                       panoUrl.toLocalFile(),
                       finalPanoUrl.toLocalFile());
-        kDebug() << "Cannot move panorama: QFile errror = " + panoFile.error();
+        kDebug() << "Cannot move panorama: QFile error = " + panoFile.error();
         return false;
     }
 
