@@ -80,6 +80,7 @@
 #include "PLEConfigSkeleton.h"
 #include "PLEAboutData.h"
 #include "StarndardEffectsFactory.h"
+#include "StandardBordersFactory.h"
 #include "global.h"
 #include "ProgressEvent.h"
 #include "BorderDrawerInterface.h"
@@ -153,7 +154,7 @@ PhotoLayoutsEditor::~PhotoLayoutsEditor()
     PLEConfigSkeleton::self()->writeConfig();
 
     if (m_canvas)
-        delete m_canvas;
+        m_canvas->deleteLater();
     if (d)
         delete d;
 
@@ -685,9 +686,11 @@ void PhotoLayoutsEditor::changeCanvasSize()
 {
     if (!m_canvas)
         return;
-    CanvasSizeDialog * ccd = new CanvasSizeDialog(m_canvas->canvasSize(), this);
-    int result = ccd->exec();
-    CanvasSize size = ccd->canvasSize();
+
+    CanvasSizeDialog* ccd = new CanvasSizeDialog(m_canvas->canvasSize(), this);
+    int result            = ccd->exec();
+    CanvasSize size       = ccd->canvasSize();
+
     if (result == KDialog::Accepted)
     {
         if (size.isValid())
@@ -701,9 +704,19 @@ void PhotoLayoutsEditor::changeCanvasSize()
         else
             KMessageBox::error(this, i18n("Invalid image size!"));
     }
+
     delete ccd;
 }
 
+void PhotoLayoutsEditor::setTemplateEditMode(bool isEnabled)
+{
+    Q_UNUSED(isEnabled);
+
+    //d->toolsWidget->setTemplateEditMode(isEnabled);
+    //d->treeWidget->setTemplateEditMode(isEnabled);
+    //m_canvas->setTemplateEditMode(isEnabled);
+}
+
 void PhotoLayoutsEditor::loadEffects()
 {
     StarndardEffectsFactory * stdEffects = new StarndardEffectsFactory( PhotoEffectsLoader::instance() );
@@ -747,6 +760,9 @@ void PhotoLayoutsEditor::loadEffects()
 
 void PhotoLayoutsEditor::loadBorders()
 {
+    StandardBordersFactory * stdBorders = new StandardBordersFactory( BorderDrawersLoader::instance() );
+    BorderDrawersLoader::registerDrawer( stdBorders );
+
     const KService::List offers = KServiceTypeTrader::self()->query("PhotoLayoutsEditor/BorderPlugin");
     foreach (const KService::Ptr& service, offers)
     {
