@@ -6,7 +6,7 @@
  * Date        : 2008-06-08
  * Description : the main window of the removeredeyes plugin
  *
- * Copyright (C) 2008-2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2008-2009 by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -194,7 +194,7 @@ RemoveRedEyesWindow::RemoveRedEyesWindow(KIPI::Interface* interface)
                                             ki18n("(c) 2008-2009, Andi Clemens"));
 
     d->about->addAuthor(ki18n("Andi Clemens"), ki18n("Author and Maintainer"),
-                        "andi dot clemens at gmx dot net");
+                        "andi dot clemens at googlemail dot com");
 
     KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
     helpMenu->menu()->removeAction(helpMenu->menu()->actions().first());
